import argparse
import logging
import os

from kubernetes import client, config
from kubernetes.client.rest import ApiException

BUILD_TAG = os.environ.get("BUILD_TAG")
FORMAT = '%(asctime)s %(levelname)s: %(message)s'
DATEFMT = '%Y-%m-%d %H:%M:%S'
logging.basicConfig(format=FORMAT, datefmt=DATEFMT, level=logging.INFO)

def delete_pvc(ns, label, core_v1):
    redis_pvc_list = core_v1.list_namespaced_persistent_volume_claim(namespace=ns,
                                                                          label_selector=label)
    for pvc in redis_pvc_list.items:
        logging.info(f"Deleting redis pvc {pvc.metadata.name} in background")
        core_v1.delete_namespaced_persistent_volume_claim(name=pvc.metadata.name, namespace=ns,
                                                          body=client.V1DeleteOptions(
                                                              propagation_policy="Background"))

def main():
    parser = argparse.ArgumentParser(description='Redis pvc upgrade.')
    parser.add_argument('--name-space', '-ns', type=str,
                        default='nsxi-platform', help='Name space of the sts')
    parser.add_argument('--label', '-l', type=str, required=True,
                        help='The label for the sts')
    args = parser.parse_args()

    try:
        if BUILD_TAG.startswith("kindtest"):
            logging.info("Skipping redis pvc upgrade for kind test")
            return
        label = args.label

        config.load_incluster_config()
        core_v1 = client.CoreV1Api()
        ns = args.name_space

        delete_pvc(ns, label, core_v1)

    except ApiException as e:
        logging.info(f"Error deleting pvc: {e}")


if __name__ == "__main__":
    main()
